==> snap-rcp-3.0.2-20160504.124053-9-sources.jar: org/esa/snap/rcp/statistics/Bundle.java <==
package org.esa.snap.rcp.statistics;
/** Localizable strings for {@link org.esa.snap.rcp.statistics}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>densityPlotDialog</i>
     * @see DensityPlotTopComponent
     */
    static String CTL_DensityPlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_DensityPlotTopComponent_HelpId");
    }
    /**
     * @return <i>Scatter Plot</i>
     * @see DensityPlotTopComponent
     */
    static String CTL_DensityPlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_DensityPlotTopComponent_Name");
    }
    /**
     * @return <i>geoCodingInfoDialog</i>
     * @see GeoCodingTopComponent
     */
    static String CTL_GeoCodingTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_GeoCodingTopComponent_HelpId");
    }
    /**
     * @return <i>Geo-Coding</i>
     * @see GeoCodingTopComponent
     */
    static String CTL_GeoCodingTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_GeoCodingTopComponent_Name");
    }
    /**
     * @return <i>histogramDialog</i>
     * @see HistogramPlotTopComponent
     */
    static String CTL_HistogramPlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HistogramPlotTopComponent_HelpId");
    }
    /**
     * @return <i>Histogram</i>
     * @see HistogramPlotTopComponent
     */
    static String CTL_HistogramPlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HistogramPlotTopComponent_Name");
    }
    /**
     * @return <i>informationDialog</i>
     * @see InformationTopComponent
     */
    static String CTL_InformationTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_InformationTopComponent_HelpId");
    }
    /**
     * @return <i>Information</i>
     * @see InformationTopComponent
     */
    static String CTL_InformationTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_InformationTopComponent_Name");
    }
    /**
     * @return <i>profilePlotDialog</i>
     * @see ProfilePlotTopComponent
     */
    static String CTL_ProfilePlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ProfilePlotTopComponent_HelpId");
    }
    /**
     * @return <i>Profile Plot</i>
     * @see ProfilePlotTopComponent
     */
    static String CTL_ProfilePlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ProfilePlotTopComponent_Name");
    }
    /**
     * @return <i>correlativePlotDialog</i>
     * @see ScatterPlotTopComponent
     */
    static String CTL_ScatterPlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ScatterPlotTopComponent_HelpId");
    }
    /**
     * @return <i>Correlative Plot</i>
     * @see ScatterPlotTopComponent
     */
    static String CTL_ScatterPlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ScatterPlotTopComponent_Name");
    }
    /**
     * @return <i>statisticsDialog</i>
     * @see StatisticsTopComponent
     */
    static String CTL_StatisticsTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_StatisticsTopComponent_HelpId");
    }
    /**
     * @return <i>Statistics</i>
     * @see StatisticsTopComponent
     */
    static String CTL_StatisticsTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_StatisticsTopComponent_Name");
    }
    private void Bundle() {}
}

==> snap-rcp-5.0.8-20170727.054422-18-sources.jar: org/esa/snap/rcp/statistics/Bundle.java <==
package org.esa.snap.rcp.statistics;
/** Localizable strings for {@link org.esa.snap.rcp.statistics}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>densityPlotDialog</i>
     * @see DensityPlotTopComponent
     */
    static String CTL_DensityPlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_DensityPlotTopComponent_HelpId");
    }
    /**
     * @return <i>Scatter Plot</i>
     * @see DensityPlotTopComponent
     */
    static String CTL_DensityPlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_DensityPlotTopComponent_Name");
    }
    /**
     * @return <i>geoCodingInfoDialog</i>
     * @see GeoCodingTopComponent
     */
    static String CTL_GeoCodingTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_GeoCodingTopComponent_HelpId");
    }
    /**
     * @return <i>Geo-Coding</i>
     * @see GeoCodingTopComponent
     */
    static String CTL_GeoCodingTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_GeoCodingTopComponent_Name");
    }
    /**
     * @return <i>histogramDialog</i>
     * @see HistogramPlotTopComponent
     */
    static String CTL_HistogramPlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HistogramPlotTopComponent_HelpId");
    }
    /**
     * @return <i>Histogram</i>
     * @see HistogramPlotTopComponent
     */
    static String CTL_HistogramPlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HistogramPlotTopComponent_Name");
    }
    /**
     * @return <i>informationDialog</i>
     * @see InformationTopComponent
     */
    static String CTL_InformationTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_InformationTopComponent_HelpId");
    }
    /**
     * @return <i>Information</i>
     * @see InformationTopComponent
     */
    static String CTL_InformationTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_InformationTopComponent_Name");
    }
    /**
     * @return <i>metadataPlotDialog</i>
     * @see MetadataPlotTopComponent
     */
    static String CTL_MetadataPlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_MetadataPlotTopComponent_HelpId");
    }
    /**
     * @return <i>Metadata Plot</i>
     * @see MetadataPlotTopComponent
     */
    static String CTL_MetadataPlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_MetadataPlotTopComponent_Name");
    }
    /**
     * @return <i>profilePlotDialog</i>
     * @see ProfilePlotTopComponent
     */
    static String CTL_ProfilePlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ProfilePlotTopComponent_HelpId");
    }
    /**
     * @return <i>Profile Plot</i>
     * @see ProfilePlotTopComponent
     */
    static String CTL_ProfilePlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ProfilePlotTopComponent_Name");
    }
    /**
     * @return <i>correlativePlotDialog</i>
     * @see ScatterPlotTopComponent
     */
    static String CTL_ScatterPlotTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ScatterPlotTopComponent_HelpId");
    }
    /**
     * @return <i>Correlative Plot</i>
     * @see ScatterPlotTopComponent
     */
    static String CTL_ScatterPlotTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ScatterPlotTopComponent_Name");
    }
    /**
     * @return <i>statisticsDialog</i>
     * @see StatisticsTopComponent
     */
    static String CTL_StatisticsTopComponent_HelpId() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_StatisticsTopComponent_HelpId");
    }
    /**
     * @return <i>Statistics</i>
     * @see StatisticsTopComponent
     */
    static String CTL_StatisticsTopComponent_Name() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_StatisticsTopComponent_Name");
    }
    private Bundle() {}
}
